==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ConsoleSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleSpecFluentImpl<A extends io.fabric8.openshift.api.model.ConsoleSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConsoleSpecFluent<A>{
  public ConsoleSpecFluentImpl() {
  }
  public ConsoleSpecFluentImpl(io.fabric8.openshift.api.model.ConsoleSpec instance) {
    this.withAuthentication(instance.getAuthentication()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder authentication;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthentication instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConsoleAuthentication getAuthentication() {
    return this.authentication!=null?this.authentication.build():null;
  }
  public io.fabric8.openshift.api.model.ConsoleAuthentication buildAuthentication() {
    return this.authentication!=null?this.authentication.build():null;
  }
  public A withAuthentication(io.fabric8.openshift.api.model.ConsoleAuthentication authentication) {
    _visitables.get("authentication").remove(this.authentication);
    if (authentication!=null){ this.authentication= new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder(authentication); _visitables.get("authentication").add(this.authentication);} return (A) this;
  }
  public java.lang.Boolean hasAuthentication() {
    return this.authentication != null;
  }
  public A withNewAuthentication(java.lang.String logoutRedirect) {
    return (A)withAuthentication(new ConsoleAuthentication(logoutRedirect));
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> withNewAuthentication() {
    return new io.fabric8.openshift.api.model.ConsoleSpecFluentImpl.AuthenticationNestedImpl();
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> withNewAuthenticationLike(io.fabric8.openshift.api.model.ConsoleAuthentication item) {
    return new io.fabric8.openshift.api.model.ConsoleSpecFluentImpl.AuthenticationNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> editAuthentication() {
    return withNewAuthenticationLike(getAuthentication());
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthentication() {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder().build());
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthenticationLike(io.fabric8.openshift.api.model.ConsoleAuthentication item) {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleSpecFluentImpl that = (ConsoleSpecFluentImpl) o;
    if (authentication != null ? !authentication.equals(that.authentication) :that.authentication != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authentication,  additionalProperties,  super.hashCode());
  }
  public class AuthenticationNestedImpl<N> extends io.fabric8.openshift.api.model.ConsoleAuthenticationFluentImpl<io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<N>> implements io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AuthenticationNestedImpl(io.fabric8.openshift.api.model.ConsoleAuthentication item) {
      this.builder = new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder(this, item);
    }
    AuthenticationNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder(this);
    }
    io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder builder;
    public N and() {
      return (N) ConsoleSpecFluentImpl.this.withAuthentication(builder.build());
    }
    public N endAuthentication() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/ConsoleSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleSpecFluentImpl<A extends io.fabric8.openshift.api.model.ConsoleSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ConsoleSpecFluent<A>{
  public ConsoleSpecFluentImpl() {
  }
  public ConsoleSpecFluentImpl(io.fabric8.openshift.api.model.ConsoleSpec instance) {
    this.withAuthentication(instance.getAuthentication()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder authentication;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildAuthentication instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ConsoleAuthentication getAuthentication() {
    return this.authentication!=null?this.authentication.build():null;
  }
  public io.fabric8.openshift.api.model.ConsoleAuthentication buildAuthentication() {
    return this.authentication!=null?this.authentication.build():null;
  }
  public A withAuthentication(io.fabric8.openshift.api.model.ConsoleAuthentication authentication) {
    _visitables.get("authentication").remove(this.authentication);
    if (authentication!=null){ this.authentication= new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder(authentication); _visitables.get("authentication").add(this.authentication);} return (A) this;
  }
  public java.lang.Boolean hasAuthentication() {
    return this.authentication != null;
  }
  public A withNewAuthentication(java.lang.String logoutRedirect) {
    return (A)withAuthentication(new ConsoleAuthentication(logoutRedirect));
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> withNewAuthentication() {
    return new io.fabric8.openshift.api.model.ConsoleSpecFluentImpl.AuthenticationNestedImpl();
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> withNewAuthenticationLike(io.fabric8.openshift.api.model.ConsoleAuthentication item) {
    return new io.fabric8.openshift.api.model.ConsoleSpecFluentImpl.AuthenticationNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> editAuthentication() {
    return withNewAuthenticationLike(getAuthentication());
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthentication() {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder().build());
  }
  public io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<A> editOrNewAuthenticationLike(io.fabric8.openshift.api.model.ConsoleAuthentication item) {
    return withNewAuthenticationLike(getAuthentication() != null ? getAuthentication(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleSpecFluentImpl that = (ConsoleSpecFluentImpl) o;
    if (authentication != null ? !authentication.equals(that.authentication) :that.authentication != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authentication,  additionalProperties,  super.hashCode());
  }
  public class AuthenticationNestedImpl<N> extends io.fabric8.openshift.api.model.ConsoleAuthenticationFluentImpl<io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<N>> implements io.fabric8.openshift.api.model.ConsoleSpecFluent.AuthenticationNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    AuthenticationNestedImpl(io.fabric8.openshift.api.model.ConsoleAuthentication item) {
      this.builder = new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder(this, item);
    }
    AuthenticationNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder(this);
    }
    io.fabric8.openshift.api.model.ConsoleAuthenticationBuilder builder;
    public N and() {
      return (N) ConsoleSpecFluentImpl.this.withAuthentication(builder.build());
    }
    public N endAuthentication() {
      return and();
    }
    
  }
  
}
